@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: TrueType.pm,v 1.12 2005/06/17 19:44:03 fredo Exp $
+#   $Id: TrueType.pm,v 1.13 2005/09/12 16:53:23 fredo Exp $
 #
 #=======================================================================
 package PDF::API2::Resource::CIDFont::TrueType;
@@ -51,7 +51,7 @@ BEGIN {
 
     @ISA = qw( PDF::API2::Resource::CIDFont );
 
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 1.12 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/06/17 19:44:03 $
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 1.13 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/09/12 16:53:23 $
 
 }
 no warnings qw[ deprecated recursion uninitialized ];
@@ -73,7 +73,7 @@ sub new {
     my %opts=();
     %opts=@opts if((scalar @opts)%2 == 0);
     $opts{-encode}||='latin1';
-    my ($ff,$data)=PDF::API2::Resource::CIDFont::TrueType::FontFile->new($pdf,$file);
+    my ($ff,$data)=PDF::API2::Resource::CIDFont::TrueType::FontFile->new($pdf,$file,@opts);
 
     $class = ref $class if ref $class;
     my $self=$class->SUPER::new($pdf,$data->{apiname}.pdfkey());
@@ -212,6 +212,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: TrueType.pm,v $
+    Revision 1.13  2005/09/12 16:53:23  fredo
+    added -isocmap option
+
     Revision 1.12  2005/06/17 19:44:03  fredo
     fixed CPAN modulefile versioning (again)
 
@@ -252,4 +255,4 @@ alfred reibenschuh
     added CVS id/log
 
 
-=cut
\ No newline at end of file
+=cut
