@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: FontFile.pm,v 1.16 2005/06/17 19:44:03 fredo Exp $
+#   $Id: FontFile.pm,v 1.17 2005/09/12 16:52:59 fredo Exp $
 #
 #=======================================================================
 package PDF::API2::Resource::CIDFont::TrueType::FontFile;
@@ -49,7 +49,7 @@ BEGIN {
 
     @ISA = qw( PDF::API2::Basic::PDF::Dict );
 
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 1.16 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/06/17 19:44:03 $
+    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 1.17 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2005/09/12 16:52:59 $
     $cmap={};
 }
 no warnings qw[ recursion uninitialized ];
@@ -407,7 +407,7 @@ sub readcffstructs
 }
 
 sub new {
-    my ($class,$pdf,$file)=@_;
+    my ($class,$pdf,$file,%opts)=@_;
     my $data={};
 
     die "cannot find font '$file' ..." unless(-f $file);
@@ -463,9 +463,10 @@ sub new {
     $data->{subname}=$font->{'name'}->find_name(2);
     $data->{subname}=~s/[\x00-\x1f\s]//og;
 
-    if(defined $font->{cmap}->read->find_ms) 
+    $font->{cmap}->read->find_ms($opts{-isocmap}||0);
+    if(defined $font->{cmap}->find_ms) 
     {
-        $data->{issymbol} = ($font->{cmap}->read->find_ms->{'Platform'} == 3 && $font->{cmap}->read->find_ms->{'Encoding'} == 0) || 0;
+        $data->{issymbol} = ($font->{cmap}->find_ms->{'Platform'} == 3 && $font->{cmap}->read->find_ms->{'Encoding'} == 0) || 0;
     } 
     else 
     {
@@ -499,19 +500,26 @@ sub new {
     $data->{capheight}=$font->{'OS/2'}->{CapHeight} || int($data->{fontbbox}->[3]*0.8);
     $data->{xheight}=$font->{'OS/2'}->{xHeight} || int($data->{fontbbox}->[3]*0.4);
 
-    if($data->{issymbol}) {
+    if($data->{issymbol}) 
+    {
         $data->{e2u}=[0xf000 .. 0xf0ff];
-    } else {
+    } 
+    else 
+    {
         $data->{e2u}=[ unpack('U*',decode('cp1252', pack('C*',0..255))) ];
     }
 
-    if(($font->{'post'}->read->{FormatType} == 3) && defined($font->{cmap}->read->find_ms)) {
+    if(($font->{'post'}->read->{FormatType} == 3) && defined($font->{cmap}->read->find_ms)) 
+    {
         $data->{g2n} = [];
-        foreach my $u (sort {$a<=>$b} keys %{$font->{cmap}->read->find_ms->{val}}) {
+        foreach my $u (sort {$a<=>$b} keys %{$font->{cmap}->read->find_ms->{val}}) 
+        {
             my $n=nameByUni($u);
             $data->{g2n}->[$font->{cmap}->read->find_ms->{val}->{$u}]=$n;
         }
-    } else {
+    } 
+    else 
+    {
         $data->{g2n} = [ map { $_ || '.notdef' } @{$font->{'post'}->read->{'VAL'}} ];
     }
 
@@ -540,17 +548,18 @@ sub new {
     else
     {
         $data->{u2g} = {};
-        my $g=0;
-        foreach my $u ($font->{'cmap'}->read->reverse) {
+
+        my $gmap=$font->{cmap}->read->find_ms->{val};
+        foreach my $u (sort {$a<=>$b} keys %{$gmap}) 
+        {
             my $uni=$u||0;
-        #    print STDERR "got g=$g u=$uni\n";
-            $data->{u2g}->{$uni}=$g;
-            $g++;
+            $data->{u2g}->{$uni}=$gmap->{$uni};
         }
         $data->{g2u}=[ map { $_ || 0 } $font->{'cmap'}->read->reverse ];
     }
 
-    if($data->{issymbol}) {
+    if($data->{issymbol}) 
+    {
         map { $data->{u2g}->{$_} ||= $font->{'cmap'}->read->ms_lookup($_) } (0xf000 .. 0xf0ff);
         map { $data->{u2g}->{$_ & 0xff} ||= $font->{'cmap'}->read->ms_lookup($_) } (0xf000 .. 0xf0ff);
     }
@@ -559,14 +568,16 @@ sub new {
 
     $data->{e2g}=[ map { $data->{u2g}->{$_ || 0} || 0 } @{$data->{e2u}} ];
     $data->{u2e}={};
-    foreach my $n (reverse 0..255) {
+    foreach my $n (reverse 0..255) 
+    {
         $data->{u2e}->{$data->{e2u}->[$n]}=$n unless(defined $data->{u2e}->{$data->{e2u}->[$n]});
     }
 
     $data->{u2n}={ map { $data->{g2u}->[$_] => $data->{g2n}->[$_] } (0 .. (scalar @{$data->{g2u}} -1)) };
 
     $data->{wx}=[];
-    foreach my $w (0..(scalar @{$data->{g2u}}-1)) {
+    foreach my $w (0..(scalar @{$data->{g2u}}-1)) 
+    {
         $data->{wx}->[$w]=int($font->{'hmtx'}->read->{'advance'}[$w]*1000/$data->{upem})
             || $data->{missingwidth};
     }
@@ -639,6 +650,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: FontFile.pm,v $
+    Revision 1.17  2005/09/12 16:52:59  fredo
+    added -isocmap option; fixed cmap handling for fallback entries
+
     Revision 1.16  2005/06/17 19:44:03  fredo
     fixed CPAN modulefile versioning (again)
 
